@@ -58,9 +58,6 @@ def _team_to_rst(name, info):
     liaisons = info.get('liaisons')
     if liaisons:
         contact_format = {'name': '', 'irc': '', 'email': ''}
-        tc_members = liaisons.get('tc_members')
-        if tc_members:
-            yield ':TC Members Liaisons: ' + ", ".join(tc_members)
         release = liaisons.get('release', contact_format)
         if release != contact_format:
             yield ':Release Liaisons: ' + ', '.join(
@@ -109,14 +106,6 @@ def _team_to_rst(name, info):
         yield ''
         yield mission
         yield ''
-    tags = info.get('tags', [])
-    if tags:
-        yield 'Team-based tags'
-        yield '---------------'
-        yield ''
-        for tag in tags:
-            yield '- :ref:`tag-%s`' % tag
-        yield ''
     yield 'Deliverables'
     yield '------------'
     yield ''
@@ -131,13 +120,6 @@ def _team_to_rst(name, info):
                 for repo in deliverable.get('repos', [])
             )
             yield ''
-            tags = deliverable.get('tags', [])
-            if tags:
-                yield ':Tags:'
-                yield ''
-                for tag in tags:
-                    yield '  - :ref:`tag-%s`' % tag
-                yield ''
     else:
         yield 'None'
     yield ''
